/*
  DRIVE:SH1107
  RESOLUTION:64*128
  INTERFACE:4W SPI
  TEST SYSTEM:ARDUINO UNO
  VOLTAGE:3.3V
  SCK-->PIN 13
  MISO-->PIN 12
  MOSI-->PIN 11
  OLED_CS-->PIN 10
  OLED_DC-->PIN 9
  OLED_RST-->PIN 8
  SD_CS-->PIN 7

  VER 1.0,2020.11.12
*/

#include <Arduino.h>
#include <U8g2lib.h>

#ifdef U8X8_HAVE_HW_SPI
#include <SPI.h>
#endif
#ifdef U8X8_HAVE_HW_I2C
#include <Wire.h>
#endif


/*
  U8g2lib Example Overview:
    Frame Buffer Examples: clearBuffer/sendBuffer. Fast, but may not work with all Arduino boards because of RAM consumption
    Page Buffer Examples: firstPage/nextPage. Less RAM usage, should work with all Arduino boards.
    U8x8 Text Only Example: No RAM usage, direct communication with display controller. No graphics, 8x8 Text only.
    
*/

U8G2_SH1107_64X128_1_4W_HW_SPI u8g2(U8G2_R0, /* cs=*/ 10, /* dc=*/ 9, /* reset=*/ 8);

// End of constructor list


void u8g2_prepare(void) {
  u8g2.setFont(u8g2_font_6x10_tf);
  u8g2.setFontRefHeightExtendedText();
  u8g2.setDrawColor(1);
  u8g2.setFontPosTop();
  u8g2.setFontDirection(0);
}

void u8g2_box_frame(uint8_t a) {
  u8g2.drawStr( 0, 0, "drawBox");
  u8g2.drawBox(5,10,20,10);
  u8g2.drawBox(10+a,15,30,7);
  u8g2.drawStr( 0, 30, "drawFrame");
  u8g2.drawFrame(5,10+30,20,10);
  u8g2.drawFrame(10+a,15+30,30,7);
}

void u8g2_disc_circle(uint8_t a) {
  u8g2.drawStr( 0, 0, "drawDisc");
  u8g2.drawDisc(10,18,9);
  u8g2.drawDisc(24+a,16,7);
  u8g2.drawStr( 0, 30, "drawCircle");
  u8g2.drawCircle(10,18+30,9);
  u8g2.drawCircle(24+a,16+30,7);
}

void u8g2_r_frame(uint8_t a) {
  u8g2.drawStr( 0, 0, "drawRFrame/Box");
  u8g2.drawRFrame(10, 10,40,40, a+5);
  u8g2.drawRBox(10, 60,40,40, a+5);
}

void u8g2_string(uint8_t a) {
  u8g2.setFontDirection(0);
  u8g2.drawStr(30+a,31, " 0");
  u8g2.setFontDirection(1);
  u8g2.drawStr(30,31+a, " 90");
  u8g2.setFontDirection(2);
  u8g2.drawStr(30-a,31, " 180");
  u8g2.setFontDirection(3);
  u8g2.drawStr(30,31-a, " 270");
}

void u8g2_line(uint8_t a) {
  u8g2.drawStr( 0, 0, "drawLine");
  u8g2.drawLine(7+a, 10, 20, 130);
  u8g2.drawLine(7+a*2, 10, 30, 130);
  u8g2.drawLine(7+a*3, 10, 40, 130);
  u8g2.drawLine(7+a*4, 10, 50, 130);
}

void u8g2_triangle(uint8_t a) {
  uint16_t offset = a;
  u8g2.drawStr( 0, 0, "drawTriangle");
  u8g2.drawTriangle(10 - offset, 20 - offset, 25 - offset, 40 - offset , 0 - offset, 30 - offset);
  u8g2.drawTriangle(10 + offset, 20 - offset, 50 + offset, 40 - offset, 25 + offset, 40 - offset);
  u8g2.drawTriangle(50 + offset, 40 + offset, 25 + offset , 40 + offset, 10 + offset, 55 + offset);
  u8g2.drawTriangle(0 - offset, 30 + offset, 25 - offset, 40 + offset, 10 - offset, 55 + offset);
}

void u8g2_ascii_1() {
  char s[2] = " ";
  uint8_t x, y;
  u8g2.drawStr( 0, 0, "ASCII Show");
  for ( y = 0; y < 20; y++ ) {
    for ( x = 0; x < 8; x++ ) {
      s[0] = y * 8+ x + 32;                        
      u8g2.drawStr(x * 8, y * 10 + 10, s);
    }
  }
}
/*
void u8g2_ascii_2() {
  char s[2] = " ";
  uint8_t x, y;
  u8g2.drawStr( 0, 0, "ASCII page 2");
  for ( y = 0; y < u8g2.getHeight() / 8; y++ ) {
    for ( x = 0; x < u8g2.getWidth() / 8; x++ ) {
      s[0] = y *4 + x + 96;
      u8g2.drawStr(x * 8, y * 8 + 10, s);
    }
  }
}
*/
void u8g2_extra_page(uint8_t a)
{
  u8g2.drawStr( 0, 0, "Unicode");
  u8g2.setFont(u8g2_font_unifont_t_symbols);
  u8g2.setFontPosTop();
  u8g2.drawUTF8(0, 24, "☀ ☁");
  switch(a) {
    case 0:
    case 1:
    case 2:
    case 3:
      u8g2.drawUTF8(a*3, 36, "☂");
      break;
    case 4:
    case 5:
    case 6:
    case 7:
      u8g2.drawUTF8(a*3, 36, "☔");
      break;
  }
}

#define cross_width 24
#define cross_height 24
static const unsigned char cross_bits[] U8X8_PROGMEM  = {
  0x00, 0x18, 0x00, 0x00, 0x24, 0x00, 0x00, 0x24, 0x00, 0x00, 0x42, 0x00, 
  0x00, 0x42, 0x00, 0x00, 0x42, 0x00, 0x00, 0x81, 0x00, 0x00, 0x81, 0x00, 
  0xC0, 0x00, 0x03, 0x38, 0x3C, 0x1C, 0x06, 0x42, 0x60, 0x01, 0x42, 0x80, 
  0x01, 0x42, 0x80, 0x06, 0x42, 0x60, 0x38, 0x3C, 0x1C, 0xC0, 0x00, 0x03, 
  0x00, 0x81, 0x00, 0x00, 0x81, 0x00, 0x00, 0x42, 0x00, 0x00, 0x42, 0x00, 
  0x00, 0x42, 0x00, 0x00, 0x24, 0x00, 0x00, 0x24, 0x00, 0x00, 0x18, 0x00, };

#define cross_fill_width 24
#define cross_fill_height 24
static const unsigned char cross_fill_bits[] U8X8_PROGMEM  = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x18, 0x64, 0x00, 0x26, 
  0x84, 0x00, 0x21, 0x08, 0x81, 0x10, 0x08, 0x42, 0x10, 0x10, 0x3C, 0x08, 
  0x20, 0x00, 0x04, 0x40, 0x00, 0x02, 0x80, 0x00, 0x01, 0x80, 0x18, 0x01, 
  0x80, 0x18, 0x01, 0x80, 0x00, 0x01, 0x40, 0x00, 0x02, 0x20, 0x00, 0x04, 
  0x10, 0x3C, 0x08, 0x08, 0x42, 0x10, 0x08, 0x81, 0x10, 0x84, 0x00, 0x21, 
  0x64, 0x00, 0x26, 0x18, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };

#define cross_block_width 14
#define cross_block_height 14
static const unsigned char cross_block_bits[] U8X8_PROGMEM  = {
  0xFF, 0x3F, 0x01, 0x20, 0x01, 0x20, 0x01, 0x20, 0x01, 0x20, 0x01, 0x20, 
  0xC1, 0x20, 0xC1, 0x20, 0x01, 0x20, 0x01, 0x20, 0x01, 0x20, 0x01, 0x20, 
  0x01, 0x20, 0xFF, 0x3F, };

  //show bit bmp
#define bmp_width 64
#define bmp_height 128
static const unsigned char bmp_bits[] U8X8_PROGMEM  = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x1e, 0x00, 0x00, 0x00,
  0x00, 0x60, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00,
  0x00, 0x60, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00,
  0x00, 0x70, 0x00, 0x80, 0x05, 0x00, 0x00, 0x00,
  0xc0, 0x73, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00,
  0x60, 0x77, 0x00, 0x40, 0x03, 0x00, 0x00, 0x00,
  0x60, 0x77, 0x00, 0x40, 0x03, 0x00, 0x00, 0x00,
  0x30, 0x7e, 0x00, 0xe0, 0x01, 0x00, 0x60, 0x00,
  0x3e, 0x7c, 0x00, 0xb0, 0x01, 0x30, 0x60, 0x00,
  0xb3, 0x7e, 0x00, 0x98, 0x00, 0x30, 0x30, 0x00,
  0xb3, 0x7e, 0x00, 0x98, 0x00, 0x30, 0xf0, 0xff,
  0xa1, 0x71, 0x00, 0x58, 0x00, 0x30, 0x38, 0xc0,
  0xe1, 0x61, 0x00, 0x68, 0x00, 0xb2, 0x19, 0x00,
  0x71, 0x67, 0x00, 0x34, 0x30, 0xfe, 0x1d, 0x00,
  0x71, 0x67, 0x00, 0x34, 0x30, 0x38, 0xfe, 0x7f,
  0x23, 0x6a, 0x00, 0x36, 0x2c, 0x38, 0xf4, 0x3f,
  0x5e, 0x7b, 0x00, 0x1b, 0x17, 0x38, 0x30, 0x31,
  0xcc, 0x73, 0x00, 0xfb, 0x0c, 0xf8, 0xb0, 0x33,
  0xcc, 0x73, 0x00, 0xfb, 0x0c, 0xfc, 0x30, 0x33,
  0x64, 0x70, 0x80, 0x1d, 0x07, 0xfc, 0x31, 0x31,
  0x84, 0x70, 0x80, 0xe0, 0x01, 0xbc, 0xff, 0xff,
  0x84, 0x59, 0xc0, 0x3c, 0x00, 0x36, 0x18, 0x31,
  0x84, 0x59, 0xc0, 0x3c, 0x00, 0x36, 0x98, 0x31,
  0x88, 0x7f, 0xc0, 0x02, 0x00, 0x37, 0x18, 0x33,
  0x70, 0x58, 0x60, 0x03, 0x00, 0x32, 0x18, 0x33,
  0x00, 0x58, 0x20, 0x03, 0x00, 0x30, 0x18, 0xb0,
  0x00, 0x58, 0x20, 0x03, 0x00, 0x30, 0xf8, 0xff,
  0x00, 0x50, 0xb0, 0x01, 0x00, 0x30, 0x00, 0x30,
  0x00, 0xd0, 0x98, 0x00, 0x00, 0x30, 0x00, 0x30,
  0x00, 0xd0, 0xd8, 0x00, 0x00, 0x30, 0x00, 0x3e,
  0x00, 0xd0, 0xd8, 0x00, 0x00, 0x30, 0x00, 0x1c,
  0x00, 0xb0, 0xc8, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0xb0, 0x4d, 0x01, 0x00, 0x00, 0x00, 0x00,
  0x00, 0xb0, 0xed, 0xfb, 0x00, 0x00, 0x00, 0x00,
  0x00, 0xb0, 0xed, 0xfb, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x30, 0x75, 0xde, 0x01, 0x00, 0x00, 0x00,
  0x00, 0x20, 0x27, 0x0c, 0x03, 0x00, 0x00, 0x00,
  0x00, 0x60, 0x37, 0x0c, 0x03, 0x00, 0x00, 0x60,
  0x00, 0x60, 0x37, 0x0c, 0x03, 0x00, 0x00, 0x60,
  0x00, 0x60, 0x30, 0x01, 0x02, 0x00, 0x00, 0x60,
  0x00, 0x40, 0x70, 0x27, 0x03, 0x00, 0x00, 0x30,
  0x00, 0x40, 0x7c, 0xbb, 0x03, 0x00, 0x00, 0x2e,
  0x00, 0x40, 0x7c, 0xbb, 0x03, 0x00, 0x00, 0x2e,
  0x00, 0xc0, 0x46, 0x31, 0x07, 0x00, 0x00, 0x39,
  0x00, 0xc0, 0x83, 0x20, 0x0c, 0x00, 0xe0, 0x38,
  0x00, 0xc0, 0xc3, 0x21, 0x18, 0x00, 0x70, 0x71,
  0x00, 0xc0, 0xc3, 0x21, 0x18, 0x00, 0x70, 0x71,
  0x00, 0x80, 0x83, 0xe0, 0x18, 0x00, 0x30, 0x4f,
  0x00, 0x00, 0x03, 0x57, 0x18, 0x00, 0x10, 0x49,
  0x00, 0x00, 0x03, 0x0c, 0x18, 0x00, 0x30, 0x69,
  0x00, 0x00, 0x03, 0x0c, 0x18, 0x00, 0x30, 0x69,
  0x00, 0x00, 0x07, 0x04, 0x0c, 0x00, 0xe0, 0x7c,
  0x00, 0x00, 0xff, 0xe0, 0x0e, 0x00, 0xc0, 0x60,
  0x00, 0x00, 0xfb, 0xc0, 0x07, 0x00, 0xc0, 0x60,
  0x00, 0x00, 0xfb, 0xc0, 0x07, 0x00, 0xc0, 0x60,
  0x00, 0x00, 0xba, 0x40, 0x00, 0x00, 0xf8, 0x26,
  0x00, 0x00, 0xbe, 0x41, 0x00, 0x00, 0xfc, 0x7f,
  0x00, 0x00, 0x3e, 0x33, 0x00, 0x00, 0xec, 0x20,
  0x00, 0x00, 0x3e, 0x33, 0x00, 0x00, 0xec, 0x20,
  0x00, 0x00, 0x74, 0x1e, 0x00, 0x00, 0xd8, 0x20,
  0x00, 0x00, 0x7c, 0x00, 0x00, 0x00, 0xb0, 0x21,
  0x00, 0x00, 0x7c, 0x00, 0x00, 0x07, 0x60, 0x33,
  0x00, 0x00, 0x7c, 0x00, 0x00, 0x07, 0x60, 0x33,
  0x80, 0x0f, 0x68, 0x00, 0x00, 0x3f, 0xc0, 0x36,
  0xe0, 0x1f, 0xe8, 0x00, 0x00, 0x7f, 0x80, 0x14,
  0xf0, 0xff, 0xe8, 0x00, 0x00, 0xe3, 0x80, 0x3d,
  0xf0, 0xff, 0xe8, 0x00, 0x00, 0xe3, 0x80, 0x3d,
  0x78, 0xf0, 0xdf, 0x01, 0x00, 0xc3, 0x01, 0x59,
  0x38, 0x80, 0xdf, 0x01, 0x00, 0x83, 0x03, 0x5a,
  0x3c, 0x00, 0x9e, 0x01, 0x00, 0x87, 0x03, 0x46,
  0x3c, 0x00, 0x9e, 0x01, 0x00, 0x87, 0x03, 0x46,
  0x1e, 0x00, 0x80, 0x07, 0x00, 0x87, 0x03, 0x66,
  0xfc, 0x00, 0x00, 0x1f, 0x00, 0x07, 0x07, 0x64,
  0xf8, 0xfb, 0x00, 0x7e, 0x00, 0x06, 0x07, 0x36,
  0xf8, 0xfb, 0x00, 0x7e, 0x00, 0x06, 0x07, 0x36,
  0xf0, 0xff, 0x01, 0xfc, 0x01, 0x06, 0x07, 0x36,
  0x80, 0x87, 0x0b, 0xf0, 0x03, 0x06, 0x0f, 0x3a,
  0x00, 0x01, 0x3f, 0xc0, 0x1f, 0x06, 0x0f, 0x19,
  0x00, 0x01, 0x3f, 0xc0, 0x1f, 0x06, 0x0f, 0x19,
  0xa8, 0x01, 0xfe, 0x40, 0x3f, 0x06, 0x8e, 0x1d,
  0xfc, 0x01, 0xf6, 0x41, 0x7e, 0x06, 0xce, 0x1c,
  0xff, 0x03, 0xfe, 0x87, 0xfa, 0x0f, 0xee, 0x0e,
  0xff, 0x03, 0xfe, 0x87, 0xfa, 0x0f, 0xee, 0x0e,
  0xc3, 0x01, 0xfe, 0x8f, 0xf3, 0x0f, 0x7e, 0x06,
  0x01, 0x00, 0xe3, 0x3e, 0xba, 0x0f, 0x3e, 0x07,
  0x01, 0x58, 0xc1, 0x7d, 0x64, 0x07, 0x1c, 0x03,
  0x01, 0x58, 0xc1, 0x7d, 0x64, 0x07, 0x1c, 0x03,
  0x01, 0xee, 0x80, 0xf9, 0x2c, 0x03, 0x80, 0x03,
  0x41, 0x83, 0x81, 0xf1, 0xd9, 0x01, 0x80, 0x01,
  0x83, 0x03, 0x83, 0xe1, 0xe3, 0x00, 0xc0, 0x01,
  0x83, 0x03, 0x83, 0xe1, 0xe3, 0x00, 0xc0, 0x01,
  0x03, 0x01, 0x87, 0xc1, 0x07, 0x00, 0xe0, 0x00,
  0x07, 0x01, 0x82, 0x81, 0x0f, 0x00, 0x70, 0x00,
  0x3f, 0x01, 0xf1, 0x00, 0x1f, 0x00, 0x30, 0x00,
  0x3f, 0x01, 0xf1, 0x00, 0x1f, 0x00, 0x30, 0x00,
  0x3c, 0x02, 0x7b, 0x00, 0x3e, 0x00, 0x38, 0x00,
  0x1c, 0xc6, 0x39, 0x00, 0x3c, 0x00, 0x3c, 0x00,
  0x0c, 0xfb, 0x30, 0x00, 0x78, 0x00, 0x78, 0x00,
  0x0c, 0xfb, 0x30, 0x00, 0x78, 0x00, 0x78, 0x00,
  0x04, 0x81, 0x71, 0x00, 0xf0, 0x00, 0xfc, 0x00,
  0x06, 0x88, 0x60, 0x00, 0xe0, 0x01, 0xe4, 0x01,
  0x06, 0x18, 0x70, 0x00, 0xc0, 0x01, 0xe4, 0x03,
  0x06, 0x18, 0x70, 0x00, 0xc0, 0x01, 0xe4, 0x03,
  0x0e, 0x38, 0x30, 0x00, 0x80, 0x03, 0xa4, 0x07,
  0x0c, 0x7c, 0x30, 0x00, 0x00, 0x07, 0xcc, 0x07,
  0x18, 0xec, 0x1e, 0x00, 0x00, 0x0f, 0xb8, 0x0f,
  0x18, 0xec, 0x1e, 0x00, 0x00, 0x0f, 0xb8, 0x0f,
  0x78, 0xce, 0x0f, 0x00, 0x00, 0x0e, 0x20, 0x1f,
  0xf0, 0x07, 0x02, 0xc0, 0x03, 0x1e, 0x20, 0x3f,
  0xc0, 0x01, 0x00, 0xf0, 0xc7, 0x1f, 0x40, 0x3d,
  0xc0, 0x01, 0x00, 0xf0, 0xc7, 0x1f, 0x40, 0x3d,
  0x00, 0x00, 0x00, 0xb8, 0xff, 0x3f, 0x40, 0x7c,
  0x00, 0x00, 0x00, 0x1c, 0x7c, 0x70, 0xc0, 0x70,
  0x00, 0x00, 0x00, 0x0c, 0x78, 0xf0, 0x80, 0x73,
  0x00, 0x00, 0x00, 0x0c, 0x78, 0xf0, 0x80, 0x73,
  0x00, 0x00, 0x00, 0x0c, 0x70, 0xe0, 0x01, 0x7c,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
};

void u8g2_bitmap_overlay(uint8_t a) {
  uint8_t frame_size = 28;

  u8g2.drawStr(0, 0, "Bitmap overlay");

  u8g2.drawStr(0, frame_size + 12, "Solid / transparent");
  u8g2.setBitmapMode(false /* solid */);
  u8g2.drawFrame(0, 10, frame_size, frame_size);
  u8g2.drawXBMP(2, 12, cross_width, cross_height, cross_bits);
  if(a & 4)
    u8g2.drawXBMP(7, 17, cross_block_width, cross_block_height, cross_block_bits);

  u8g2.setBitmapMode(true /* transparent*/);
  u8g2.drawFrame(frame_size + 5, 10, frame_size, frame_size);
  u8g2.drawXBMP(frame_size + 7, 12, cross_width, cross_height, cross_bits);
  if(a & 4)
    u8g2.drawXBMP(frame_size + 12, 17, cross_block_width, cross_block_height, cross_block_bits);
}

void u8g2_bitmap_modes(uint8_t transparent) {
  const uint8_t frame_size = 24;  //2020.11.04,24

  u8g2.drawBox(0, frame_size * 0.5 , frame_size * 5.25, frame_size);  //2020.11.10
  u8g2.drawStr(frame_size * 0.5, 50, "Black");
  u8g2.drawStr(frame_size * 2, 50, "White");
  u8g2.drawStr(frame_size * 3.5, 50, "XOR");
  
  if(!transparent) {
    u8g2.setBitmapMode(false /* solid */);
    u8g2.drawStr(0, 0, "Solid bitmap");
  } else {
    u8g2.setBitmapMode(true /* transparent*/);
    u8g2.drawStr(0, 0, "Transparent bitmap");
  }
  u8g2.setDrawColor(0);// Black
  u8g2.drawXBMP(frame_size * 0.5, 24, cross_width, cross_height, cross_bits);
  u8g2.setDrawColor(1); // White
  u8g2.drawXBMP(frame_size * 2, 24, cross_width, cross_height, cross_bits);
  u8g2.setDrawColor(2); // XOR
  u8g2.drawXBMP(frame_size * 3.5, 24, cross_width, cross_height, cross_bits);
}

void Show_PIC()
{
  u8g2.drawXBMP(0, 0, bmp_width, bmp_height, bmp_bits);
}

uint8_t draw_state = 0;

void draw(void) {
  u8g2_prepare();
  switch(draw_state >> 3) {
    case 0: u8g2_ascii_1(); break;
//    case 1: u8g2_ascii_2(); break;
    case 1: u8g2_box_frame(draw_state&7); break;
    case 2: u8g2_disc_circle(draw_state&7); break;
    case 3: u8g2_r_frame(draw_state&7); break;
    case 4: u8g2_string(draw_state&7); break;
    case 5: u8g2_line(draw_state&7); break;
    case 6: u8g2_triangle(draw_state&7); break;   
    case 7: u8g2_extra_page(draw_state&7); break; 
    case 8: Show_PIC();  break;
 //     delay(1500);
 /*   case 8: u8g2_bitmap_modes(0); break;
    case 9: u8g2_bitmap_modes(1); break;
    case 10: u8g2_bitmap_overlay(draw_state&7); break;*/
  }
}


void setup(void) {

  /* U8g2 Project: SSD1306 Test Board */
  pinMode(10, OUTPUT);
  pinMode(9, OUTPUT);
  digitalWrite(10, 0);
  digitalWrite(9, 0);

  /* U8g2 Project: T6963 Test Board */
  //pinMode(18, OUTPUT);
  //digitalWrite(18, 1);

  /* U8g2 Project: KS0108 Test Board */
  //pinMode(16, OUTPUT);
  //digitalWrite(16, 0);

  u8g2.begin();
  //  u8x8.begin();
  //u8g2.setFlipMode(0);
}

void loop(void) {
  // picture loop
  u8g2.firstPage();
  do {
    draw();
  } while ( u8g2.nextPage() );

  // increase the state
  draw_state++;
  if ( draw_state >= 10 * 8 )
    draw_state = 0;

  // delay between each page
  delay(150);

}
